@@ -215,7 +215,7 @@ class TranslationBaseModelAdmin(BaseModelAdmin):
         if exclude_languages:
             excl_languages = exclude_languages
         exclude = []
-        for orig_fieldname, translation_fields in self.trans_opts.fields.iteritems():
+        for orig_fieldname, translation_fields in self.trans_opts.fields.items():
             for tfield in translation_fields:
                 language = tfield.name.split('_')[-1]
                 if language in excl_languages and tfield not in exclude:
@@ -321,7 +321,7 @@ class TranslationInlineModelAdmin(TranslationBaseModelAdmin, InlineModelAdmin):
         # is displayed above the new fieldsets.
         if self.declared_fieldsets:
             return self._do_get_fieldsets_pre_form_or_formset()
-        form = self.get_formset(request, obj).form
+        form = self.get_formset(request, obj, fields=None).form
         return self._do_get_fieldsets_post_form_or_formset(request, form, obj)
 
 
